# $Header: /usr/local/cvsroot/nsd/aolserver/tcl/charsets.tcl,v 1.2 2000/06/29 20:15:16 mayoff Exp $

if {[info tclversion] >= 8.1} {

    proc _ns_multipartformdata_p {} {
	set type [string tolower [ns_set iget [ns_conn headers] content-type]]
	return [expr {[string compare [ns_conn method] POST] == 0
	    && [string match *multipart/form-data* $type]}]
    }

    proc _ns_form_exists_p {} {
	global _ns_form
	return [info exists _ns_form]
    }

    proc _ns_form_needs_conversion_p {} {
	return [expr {[_ns_multipartformdata_p] && ![_ns_form_exists_p]}]
    }

    proc _ns_convertformcharset {charset} {
	global _ns_form

	set newform [ns_set create [ns_set name $_ns_form]]
	set encoding [ns_encodingforcharset $charset]

	set n [ns_set size $_ns_form]
	for {set i 0} {$i < $n} {incr i} {
	    set key [ns_set key $_ns_form $i]
	    set value [ns_set value $_ns_form $i]

	    if {[string match $key "*.*"]} {
		ns_set put $newform $key $value
	    } else {
		set value [ns_set value $_ns_form $i]
		set value [encoding convertfrom $encoding $value]
		ns_set put $newform $key $value
	    }
	}

	ns_set free $_ns_form
	set _ns_form $newform
    }

    proc ns_formfieldcharset {name} {

	set charset ""

	if [_ns_multipartformdata_p] {

	    if [_ns_form_exists_p] {

		# Form was already parsed; cannot be converted now.

		set form [ns_getform]
		if {[string compare $form ""] != 0} {
		    set charset [ns_set get $form $name]
		}

	    } else {

		# Parse the form.

		set form [ns_getform]

		if {[string compare $form ""] != 0} {

		    set charset [ns_set get $form $name]

		    if {[string compare $charset ""] != 0} {
			_ns_convertformcharset $charset
		    }

		}

	    }

	} else {
	    set query [ns_conn query]

	    regexp "&$name=(\[^&]*)" "&$query" junk charset
	}

	if {[string compare $charset ""] != 0} {
	    ns_urlcharset $charset

	    # Make sure the form gets parsed/converted with this charset.
	    ns_getform
	}
    }

    proc ns_cookiecharset {name} {
	set cookies [split [ns_set iget [ns_conn headers] cookie] ";"]

	set charset ""

	foreach cookie $cookies {
	    set cookie [string trim $cookie]
	    if [regexp "$name=(.*)" $cookie junk charset] {
		break
	    }
	}

	ns_log Notice "charset=$charset"

	if {[string compare $charset ""] != 0} {

	    ns_urlcharset $charset

	    if [_ns_multipartformdata_p] {
		if ![_ns_form_exists_p] {
		    # Haven't parsed the form yet, so we can parse and
		    # convert it now.
		    ns_getform
		    _ns_convertformcharset $charset
		}
	    } else {
		# Make sure the form gets parsed/converted with this charset.
		ns_getform
	    }

	}
    }

    proc ns_encodingfortype {type} {
	set type [string trim [string tolower $type]]
	if {[string length $type] == 0} {
	    return binary
	} elseif {[regexp {;[ \t\r\n]*charset[ \t\r\n]*=([^;]*)} $type junk charset]} {
	    return [ns_encodingforcharset [string trim $charset]]
	} elseif {[string match text/* $type]} {
	    return [ns_encodingforcharset [ns_config ns/parameters OutputCharset iso-8859-1]]
	} else {
	    return binary
	}
    }

    proc ns_choosecharset {args} {

	set preferred_charsets [ns_config ns/parameters PreferredCharsets \
	    {utf-8 iso-8859-1}]
	set default_charset [ns_config ns/parameters DefaultCharset iso-8859-1]

	for {set i 0; set n [llength $args]} {$i < $n} {incr i} {
	    set arg [lindex $args $i]
	    switch -- $arg {
		-pref* {
		    incr i
		    if {$i >= $n} {
			error "Missing argument for $arg"
		    }
		    set preferred_charsets [lindex $args $i]
		}
		default {
		    error "Usage: ns_choosecharset ?-preference charset-list?"
		}
	    }
	}

	# Figure out what character sets the client will accept.

	set accept_charset_header [string tolower \
	    [ns_set iget [ns_conn headers] accept-charset]]
	regsub -all {[ \t\r\n]} $accept_charset_header {} accept_charset_header

	if {[string length $accept_charset_header] == 0} {
	    # The client didn't specify any character sets, so send him
	    # the default.
	    return $default_charset
	}

	if {[string first ";q=" $accept_charset_header] == -1} {

	    # No q values; just use the header order.

	    set accept_charsets [split $accept_charset_header ,]

	} else {

	    # At least one q value; sort by q values.

	    set list {}
	    foreach acharset [split $accept_charset_header ,] {
		set i [string first ";q=" $acharset]
		if {$i == -1} {
		    lappend list [list $acharset 1.0]
		} else {
		    incr i -1
		    set charset [string range $acharset 0 $i]
		    incr i 4
		    set q [string range $acharset $i end]
		    if {![regexp {^[01](\.[0-9]{0,3})?} $q]} {
			set q 0.0
		    } elseif {$q > 1.0} {
			set q 1.0
		    }
		    if {$q > 0.0} {
			lappend list [list $charset $q]
		    }
		}
	    }

	    set accept_charsets {}
	    foreach pair [lsort -decreasing -real -index 1 $list] {
		lappend accept_charsets [lindex $pair 0]
	    }
	}

	if {[llength $accept_charsets] == 0} {
	    # No charsets had a q value > 0.
	    return $default_charset
	}

	foreach charset $preferred_charsets {
	    if {[lsearch -exact $accept_charsets $charset] != -1} {
		# Return the first preferred charset that is acceptable
		# to the client.
		return $charset
	    }
	}

	set supported_charsets [ns_charsets]
	foreach charset $accept_charsets {
	    if {[lsearch -exact $supported_charsets $charset] != -1} {
		# Return the first acceptable charset that we support.
		return $charset
	    }
	}

	return $default_charset
    }

}

foreach cmd {ns_charsets ns_startcontent ns_urlcharset ns_formfieldcharset ns_cookiecharset ns_encodingforcharset ns_encodingfortype ns_choosecharset} {
    if {[string compare [info command $cmd] ""] == 0} {
	proc $cmd {args} {}
    }
}

