#
# $Header: /usr/local/cvsroot/nsd/aolserver/tcl/tclcache.tcl,v 1.4 2001/01/15 18:32:39 mayoff Exp $
#

#
# tclcache.tcl --
#
#      Support for caching Tcl-page bytecodes.
#

if { ![string equal [info commands "ns_cache"] ""] } {
    ns_cache create util_file_contents_cached -thread 1 \
        -size [ns_config "ns/server/[ns_info server]" SourceCacheSize 5000000]

    # Return a cookie that will be different if the file changes
    # in any way.
    proc util_file_cookie {filename} {
        file stat $filename stat
        return [list $stat(mtime) $stat(ctime) $stat(ino) $stat(dev)]
    }

    # Return the entire contents of a file.
    proc util_file_contents {filename} {
        set fd [open $filename]
        set contents [read $fd]
        close $fd
        return $contents
    }

    # Get the contents of a file from the cache or disk.
    proc util_file_contents_cached {filename} {

        set current_cookie [util_file_cookie $filename]

        set cached_p [ns_cache get util_file_contents_cached $filename pair]

        if {$cached_p} {
            set cached_cookie [lindex $pair 0]

            if {![string equal $cached_cookie $current_cookie]} {
                ns_cache flush util_file_contents_cached $filename
                set cached_p 0
            }
        }

        if {!$cached_p} {
            # Now cache the Tcl_Obj in a thread-local cache.
            set pair [ns_cache eval util_file_contents_cached $filename {
                list $current_cookie [util_file_contents $filename]
            }]
        }

        return [lindex $pair 1]
    }

    # And here's the magic part.  We're using "for" here to translate the
    # text source file into bytecode, which will be associated with the 
    # Tcl_Obj we just cached (as its internal representation).  "eval"
    # doesn't do this as the eval provided in Tcl uses the TCL_EVAL_DIRECT
    # flag, and hence interprets the text directly.
    proc source_cached {filename} {
         uplevel [for [util_file_contents_cached $filename] {0} {} {}]
    }
}
