#
# nsd.server1.tcl --  AOLserver Startup Script
# For ACS >= 3.4.x and OpenACS.  Configured for PostgreSQL DB.
#
# $Id: nsd.server1.tcl,v 1.3 2001/04/12 20:53:29 biggers Exp $
#
#   Translated on Tue Nov 14 12:28:40 EST 2000
#     from  acs3.4.2/www/install/service-name.ini --
#     (.ini format) with /usr/local/aolsrv_3.0/bin/translate-ini
#     (modified its parameter "region"!)
#
#   This is a Tcl script that is sourced when AOLserver starts up.
#   A detailed reference is in "doc/config.txt".
#
#   NOTE:  Some modules are commented-out in this file because
#          they require configuration and/or passwords changed
#          before using.  They are nsssl, nscp, and nsperm.

ns_log Notice "nsd.someServer.tcl: starting to read config file..."

#
# Set some Tcl variables that are commonly used throughout this file.
#
set httpport		8000;		    ## use 80  - (Open)ACS
set httpsport		8443;		    ## use 443 - (Open)ACS

set hostname		"localhost.localdomain";  # [ns_info hostname]
set address		127.0.0.1;	    # [ns_info address]

set servername		server1
set serverdesc		"AOLserver 3.0+ad6"

set homedir	/usr/local/aolsrv_3.2+ad12; # [file dirname [ns_info config]]
set bindir	${homedir}/bin;		    # [file dirname [ns_info nsd]]

## set pagedir		/web/${servername};  ## (Open)ACS
## set pageroot		${pagedir}/www;      ## (Open)ACS
set pageroot		${homedir}/servers/${servername}/pages

set directoryfile	"index.tcl,index.adp,index.html,index.htm"

# nsssl: loads IFF keyfile.pem and certfile.pem exist...
set sslkeyfile	 ${homedir}/servers/${servername}/modules/nsssl/keyfile.pem
set sslcertfile  ${homedir}/servers/${servername}/modules/nsssl/certfile.pem

set db_user		nsadmin;	    ## Oracle or PG tablespace
set db_pw		yowzippy;
set db_verbose		Off
set db_tblinfo		On
set db_driver		postgres;	    ## ora8 for Oracle

set db_idle		'1000000000';	    ## for ACS...
set db_open		'1000000000';	    ## for ACS...

set db_datasrc		"localhost:5432:openacs"; # ACS: "" (empty string)
set db_default		pg_mydb;	    # (Open)ACS: "main"

# ------------------------------------  acs3.4.2/www/install/service-name.ini

ns_section "ns/servers"
ns_param ${servername} ${serverdesc}

ns_section "ns/server/${servername}/tcl"
## ns_param Library      "${pagedir}/tcl";	 ## (Open)ACS; addt'l TCL libs

ns_section "ns/db/drivers"
ns_param postgres     nspostgres.so
## ns_param ora8         "ora8.so"

ns_section "ns/db/pool/main"
ns_param Driver       $db_driver
ns_param Connections  4
ns_param DataSource   $db_datasrc
ns_param MaxIdle      $db_idle
ns_param MaxOpen      $db_open
ns_param User         $db_user
ns_param Password     $db_pw
ns_param Verbose      $db_verbose
ns_param ExtendedTableInfo $db_tblinfo

ns_section "ns/db/pool/subquery"
ns_param Driver       $db_driver
ns_param Connections  4
ns_param DataSource   $db_datasrc
ns_param MaxIdle      $db_idle
ns_param MaxOpen      $db_open
ns_param User         $db_user
ns_param Password     $db_pw
ns_param Verbose      $db_verbose
ns_param ExtendedTableInfo $db_tblinfo

ns_section "ns/db/pool/log"
ns_param Driver       $db_driver
ns_param Connections  3
ns_param DataSource   $db_datasrc
ns_param MaxIdle      $db_idle
ns_param MaxOpen      $db_open
ns_param User         $db_user
ns_param Password     $db_pw
ns_param Verbose      $db_verbose
ns_param ExtendedTableInfo $db_tblinfo

ns_section "ns/db/pool/pg_mydb"
ns_param Driver       postgres
ns_param Connections  4
ns_param Datasource  "localhost:5432:mydb"
ns_param User         $db_user

ns_section "ns/db/pools"
ns_param pg_mydb        "mydb bookbiz DB; PostgreSQL pool"
## ns_param main           "main";		    # (Open)ACS
## ns_param subquery       "subquery"
## ns_param log            "log"

ns_section "ns/parameters"
ns_param User		"nsadmin"
ns_param ServerLog	"${homedir}/log/${servername}-error.log"
ns_param Home		"${homedir}"
ns_param StackSize	500000;		    ## for .adp & (Open)ACS
## ns_param auxconfigdir  "${pagedir}/parameters";  ## (Open)ACS
ns_param Debug		true;		    # source files w.r.t. logfile
## ns_param MaxKeepAlive	0;		    # !! (Open)ACS, NO??

ns_section "ns/threads"
ns_param  SystemScope	on;		    # ??
## ns_param  mutexmeter	true;		    # !BREAKS AOLsrv - lock contention 

ns_section "ns/server/${servername}"
ns_param PageRoot	${pageroot}
ns_param DirectoryFile	${directoryfile}
ns_param Webmaster	webmaster@${hostname}
ns_param NoticeBgColor	"#ffffff"
ns_param EnableTclPages "On"
ns_param NotFoundResponse "/global/file-not-found.html"
ns_param ServerBusyResponse "/global/busy.html"
ns_param ServerInternalErrorResponse "/global/error.html"
ns_param MaxThreads	50
ns_param MaxBusyThreads	20
ns_param MaxWait	 2
## ns_param globalstats	true;       # !! for ACS?? Enable built-in statistics
## ns_param urlstats	true;	    # Enable URL statistics
## ns_param maxurlstats	1000;	    # max # of URL's to do stats on

ns_section "ns/server/${servername}/db"
ns_param Pools          "*"
ns_param DefaultPool    $db_default

ns_section "ns/server/${servername}/adp"
ns_param Map            "/*.adp"

ns_section "ns/server/service_name/module/nscache"
ns_param CacheADP       on;

ns_section "ns/server/${servername}/module/nslog"
ns_param EnableHostnameLookup  Off
ns_param File		"${homedir}/log/${servername}.log"
ns_param LogCombined	On
ns_param LogRefer	On
ns_param LogUserAgent	On
ns_param RollDay	"*"
ns_param RollFmt	"%d%b%g";  # was "%Y-%m-%d-%H:%M", per "man strftime"
ns_param rollonsignal	On;	# Roll BOTH logs on SIGHUP
ns_param rolllog	Off;	# Should we roll log (by time-of-day)?
ns_param rollhour	0;	# Time to roll log
ns_param maxbackup	5;	# Max number to keep around when rolling

ns_section "ns/server/${servername}/module/nsperm"
ns_param model			Small
ns_param enablehostnamelookup	Off

ns_section "ns/server/${servername}/module/nssock"
ns_param Hostname	$hostname
ns_param Address	$address
ns_param Port		$httpport
ns_param timeout	120
## ns_param closewait	0		     # not ACS???  breaks browsers!
					     # forwarding http => https??
ns_section "ns/server/${servername}/module/nsssl"
ns_param Hostname	$hostname
ns_param Address	$address
ns_param Port		$httpsport
ns_param CertFile	$sslcertfile
ns_param KeyFile	$sslkeyfile

ns_section "ns/server/${servername}/modules"
ns_param nsperm		"nsperm.so"
ns_param nssock		"nssock.so"
ns_param nslog		"nslog.so"
ns_param nssha1		"nssha1.so"

if { [file exists $sslcertfile] && [file exists $sslkeyfile] } {
    ns_param nsssl	"nsssl.so"
} else {
    ns_log Warning "nsd.${servername}.tcl: nsssl not loaded because key/cert files do not exist."
}

ns_section "ns/server/${servername}/MimeTypes"
ns_param Default	"text/plain"
ns_param NoExtension	"text/plain"
ns_param .pcd		"image/x-photo-cd"
ns_param .prc		"application/x-pilot"

ns_log Notice "nsd.${servername}.tcl: finished reading config file."
